@@ -28,7 +28,6 @@ from iredis.utils import DSN
 def test_command_entry_tty(is_tty, raw_arg_is_raw, final_config_is_raw, config):
     # is tty + raw -> raw
     with patch("sys.stdout.isatty") as patch_tty:
-
         patch_tty.return_value = is_tty
         if raw_arg_is_raw is None:
             call = ["iredis"]
@@ -175,6 +174,19 @@ def test_command_shell_options_higher_priority():
                 verify_ssl=None,
             ),
         ),
+        (
+            "redis://username:pass@word@localhost:12345/2",
+            DSN(
+                scheme="redis",
+                host="localhost",
+                port=12345,
+                path=None,
+                db=2,
+                username="username",
+                password="pass@word",
+                verify_ssl=None,
+            ),
+        ),
         (
             "redis://username@localhost:12345",
             DSN(
